@@ -8,20 +8,24 @@
  * http://atomicparsley.sourceforge.net/mpeg-4files.html
  */
 
-#include <glib.h>
+#include <stdint.h>
+#include <stdlib.h>
 #include <string.h>
-#include <audacious/debug.h>
+#include <unistd.h>
+
 #include <libaudcore/vfs.h>
 
-static const gchar * const hier[] = {"moov", "udta", "meta", "ilst", "covr",
- "data"};
-static const gint skip[] = {0, 0, 4, 0, 0, 8};
+static const char * const hier[] = {"moov", "udta", "meta", "ilst", "covr", "data"};
+static const int skip[] = {0, 0, 4, 0, 0, 8};
 
-gboolean read_itunes_cover (const gchar * filename, VFSFile * file, void * *
- data, gint64 * size)
+bool_t read_itunes_cover (const char * filename, VFSFile * file, void * *
+ data, int64_t * size)
 {
-    guchar b[8];
-    gint bsize;
+    unsigned char b[8];
+    int bsize;
+
+    * data = NULL;
+    * size = 0;
 
     /* Check for ftyp frame. */
 
@@ -29,19 +33,17 @@ gboolean read_itunes_cover (const gchar * filename, VFSFile * file, void * *
         return FALSE;
     if ((bsize = (b[0] << 24) | (b[1] << 16) | (b[2] << 8) | b[3]) < 8)
         return FALSE;
-    if (strncmp ((gchar *) b + 4, "ftyp", 4))
+    if (strncmp ((char *) b + 4, "ftyp", 4))
         return FALSE;
     if (vfs_fseek (file, bsize - 8, SEEK_CUR))
         return FALSE;
 
-    AUDDBG ("Found ftyp frame, size = %d.\n", bsize);
-
-    gint64 stop = G_MAXINT64;
-    gint64 at = bsize;
+    int64_t stop = INT64_MAX;
+    int64_t at = bsize;
 
     /* Descend into frame hierarchy. */
 
-    for (gint h = 0; h < G_N_ELEMENTS (hier); h ++)
+    for (int h = 0; h < sizeof hier / sizeof hier[0]; h ++)
     {
         while (1)
         {
@@ -50,7 +52,7 @@ gboolean read_itunes_cover (const gchar * filename, VFSFile * file, void * *
             if ((bsize = (b[0] << 24) | (b[1] << 16) | (b[2] << 8) | b[3]) < 8
              || at + bsize > stop)
                 return FALSE;
-            if (! strncmp ((gchar *) b + 4, hier[h], 4))
+            if (! strncmp ((char *) b + 4, hier[h], 4))
                 break;
             if (vfs_fseek (file, bsize - 8, SEEK_CUR))
                 return FALSE;
@@ -58,8 +60,6 @@ gboolean read_itunes_cover (const gchar * filename, VFSFile * file, void * *
             at += bsize;
         }
 
-        AUDDBG ("Found %s frame at %d, size = %d.\n", hier[h], (gint) at, bsize);
-
         stop = at + bsize;
         at += 8;
 
@@ -75,12 +75,14 @@ gboolean read_itunes_cover (const gchar * filename, VFSFile * file, void * *
 
     /* We're there. */
 
+    * data = malloc (stop - at);
     * size = stop - at;
-    * data = g_malloc (stop - at);
 
     if (vfs_fread (* data, 1, stop - at, file) != stop - at)
     {
-        g_free (* data);
+        free (* data);
+        * data = NULL;
+        * size = 0;
         return FALSE;
     }
 
