@@ -23,6 +23,7 @@
 #include <audacious/drct.h>
 #include <audacious/i18n.h>
 #include <audacious/plugin.h>
+#include <libaudcore/hook.h>
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
 
@@ -46,7 +47,8 @@ static void show_error_message (const gchar * text);
 
 AUD_IFACE_PLUGIN
 (
-    .name = "Winamp Classic Interface",
+    .name = N_("Winamp Classic Interface"),
+    .domain = PACKAGE,
     .init = skins_init,
     .cleanup = skins_cleanup,
     .configure = skins_configure,
@@ -176,3 +178,14 @@ static void show_error_message (const gchar * text)
 {
     audgui_simple_message (& error_win, GTK_MESSAGE_ERROR, _("Error"), _(text));
 }
+
+bool_t handle_window_close (void)
+{
+    bool_t handled = FALSE;
+    hook_call ("window close", & handled);
+
+    if (! handled)
+        aud_drct_quit ();
+
+    return TRUE;
+}
