@@ -23,10 +23,10 @@
  *  Audacious or using our public API to be a derived work.
  */
 
+#include <string.h>
 #include <gtk/gtk.h>
 
 #include <audacious/drct.h>
-#include <audacious/gtk-compat.h>
 #include <audacious/i18n.h>
 #include <audacious/misc.h>
 #include <audacious/playlist.h>
@@ -35,6 +35,7 @@
 
 #include "actions-equalizer.h"
 #include "config.h"
+#include "plugin.h"
 #include "skins_cfg.h"
 #include "ui_equalizer.h"
 #include "ui_main.h"
@@ -46,8 +47,6 @@
 #include "ui_skinned_window.h"
 #include "util.h"
 
-#include "images/audacious_eq.xpm"
-
 enum PresetViewCols {
     PRESET_VIEW_COL_NAME,
     PRESET_VIEW_N_COLS
@@ -103,12 +102,7 @@ static void free_presets (Index * presets)
 void equalizerwin_set_shape (void)
 {
     gint id = config.equalizer_shaded ? SKIN_MASK_EQ_SHADE : SKIN_MASK_EQ;
-
-#ifdef MASK_IS_REGION
     gtk_widget_shape_combine_region (equalizerwin, active_skin->masks[id]);
-#else
-    gtk_widget_shape_combine_mask (equalizerwin, active_skin->masks[id], 0, 0);
-#endif
 }
 
 static void
@@ -211,12 +205,6 @@ equalizerwin_close_cb(void)
     equalizerwin_show(FALSE);
 }
 
-static gboolean equalizerwin_delete(GtkWidget *widget, void *data)
-{
-    aud_drct_quit ();
-    return TRUE;
-}
-
 static void eqwin_volume_set_knob (void)
 {
     gint pos = hslider_get_pos (equalizerwin_volume);
@@ -380,8 +368,6 @@ static void eq_win_draw (GtkWidget * window, cairo_t * cr)
 static void
 equalizerwin_create_window(void)
 {
-    GdkPixbuf *icon;
-
     equalizerwin = window_new (& config.equalizer_x, & config.equalizer_y, 275,
      config.equalizer_shaded ? 14 : 116, FALSE, config.equalizer_shaded,
      eq_win_draw);
@@ -393,18 +379,11 @@ equalizerwin_create_window(void)
                                  GTK_WINDOW(mainwin));
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(equalizerwin), TRUE);
 
-    icon = gdk_pixbuf_new_from_xpm_data((const gchar **) audacious_eq_icon);
-    gtk_window_set_icon(GTK_WINDOW(equalizerwin), icon);
-    g_object_unref(icon);
-
     gtk_widget_set_app_paintable(equalizerwin, TRUE);
 
-    g_signal_connect(equalizerwin, "delete_event",
-                     G_CALLBACK(equalizerwin_delete), NULL);
-    g_signal_connect(equalizerwin, "button_press_event",
-                     G_CALLBACK(equalizerwin_press), NULL);
-    g_signal_connect ((GObject *) equalizerwin, "key-press-event", (GCallback)
-     mainwin_keypress, 0);
+    g_signal_connect (equalizerwin, "delete-event", (GCallback) handle_window_close, NULL);
+    g_signal_connect (equalizerwin, "button-press-event", (GCallback) equalizerwin_press, NULL);
+    g_signal_connect (equalizerwin, "key-press-event", (GCallback) mainwin_keypress, NULL);
 }
 
 static void equalizerwin_destroyed (void)
@@ -882,7 +861,7 @@ static GtkWidget * equalizerwin_create_list_window (Index * preset_list,
     g_signal_connect(*window, "destroy",
                      G_CALLBACK(gtk_widget_destroyed), window);
 
-    vbox = gtk_vbox_new(FALSE, 10);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
     gtk_container_add(GTK_CONTAINER(*window), vbox);
 
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -928,7 +907,7 @@ static GtkWidget * equalizerwin_create_list_window (Index * preset_list,
         gtk_box_pack_start(GTK_BOX(vbox), *entry, FALSE, FALSE, 0);
     }
 
-    bbox = gtk_hbutton_box_new();
+    bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing(GTK_BOX(bbox), 5);
     gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
@@ -1117,8 +1096,9 @@ action_equ_save_auto_preset(void)
 
     if (name != NULL)
     {
-        gtk_entry_set_text(GTK_ENTRY(equalizerwin_save_auto_entry),
-                           g_basename(name));
+        char * base = g_path_get_basename (name);
+        gtk_entry_set_text ((GtkEntry *) equalizerwin_save_auto_entry, base);
+        g_free (base);
         str_unref (name);
     }
 }
