@@ -25,13 +25,13 @@
 
 #include <math.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/time.h>
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
 #include <audacious/drct.h>
-#include <audacious/gtk-compat.h>
 #include <audacious/i18n.h>
 #include <audacious/misc.h>
 #include <libaudcore/audstrings.h>
@@ -42,6 +42,7 @@
 #include "actions-playlist.h"
 #include "config.h"
 #include "dnd.h"
+#include "plugin.h"
 #include "skins_cfg.h"
 #include "ui_equalizer.h"
 #include "ui_hints.h"
@@ -147,12 +148,7 @@ mainwin_set_shade(gboolean shaded)
 void mainwin_set_shape (void)
 {
     gint id = config.player_shaded ? SKIN_MASK_MAIN_SHADE : SKIN_MASK_MAIN;
-
-#ifdef MASK_IS_REGION
     gtk_widget_shape_combine_region (mainwin, active_skin->masks[id]);
-#else
-    gtk_widget_shape_combine_mask (mainwin, active_skin->masks[id], 0, 0);
-#endif
 }
 
 static void mainwin_vis_set_type (VisType mode)
@@ -562,42 +558,42 @@ gboolean mainwin_keypress (GtkWidget * widget, GdkEventKey * event,
 
     switch (event->keyval)
     {
-        case GDK_minus:
+        case GDK_KEY_minus:
             mainwin_set_volume_diff (-5);
             break;
-        case GDK_plus:
+        case GDK_KEY_plus:
             mainwin_set_volume_diff (5);
             break;
-        case GDK_Left:
-        case GDK_KP_Left:
-        case GDK_KP_7:
+        case GDK_KEY_Left:
+        case GDK_KEY_KP_Left:
+        case GDK_KEY_KP_7:
             aud_drct_seek (aud_drct_get_time () - 5000);
             break;
-        case GDK_Right:
-        case GDK_KP_Right:
-        case GDK_KP_9:
+        case GDK_KEY_Right:
+        case GDK_KEY_KP_Right:
+        case GDK_KEY_KP_9:
             aud_drct_seek (aud_drct_get_time () + 5000);
             break;
-        case GDK_KP_4:
+        case GDK_KEY_KP_4:
             aud_drct_pl_prev ();
             break;
-        case GDK_KP_6:
+        case GDK_KEY_KP_6:
             aud_drct_pl_next ();
             break;
-        case GDK_KP_Insert:
+        case GDK_KEY_KP_Insert:
             audgui_jump_to_track ();
             break;
-        case GDK_space:
+        case GDK_KEY_space:
             aud_drct_pause();
             break;
-        case GDK_Tab: /* GtkUIManager does not handle tab, apparently. */
+        case GDK_KEY_Tab: /* GtkUIManager does not handle tab, apparently. */
             if (event->state & GDK_SHIFT_MASK)
                 action_playlist_prev ();
             else
                 action_playlist_next ();
 
             break;
-        case GDK_ISO_Left_Tab:
+        case GDK_KEY_ISO_Left_Tab:
             action_playlist_prev ();
             break;
         default:
@@ -1250,7 +1246,7 @@ mainwin_create_widgets(void)
 
     mainwin_close = button_new (9, 9, 18, 0, 18, 9, SKIN_TITLEBAR, SKIN_TITLEBAR);
     window_put_widget (mainwin, FALSE, mainwin_close, 264, 3);
-    button_on_release (mainwin_close, (ButtonCB) aud_drct_quit);
+    button_on_release (mainwin_close, (ButtonCB) handle_window_close);
 
     mainwin_rew = button_new (23, 18, 0, 0, 0, 18, SKIN_CBUTTONS, SKIN_CBUTTONS);
     window_put_widget (mainwin, FALSE, mainwin_rew, 16, 88);
@@ -1382,7 +1378,7 @@ mainwin_create_widgets(void)
 
     mainwin_shaded_close = button_new (9, 9, 18, 0, 18, 9, SKIN_TITLEBAR, SKIN_TITLEBAR);
     window_put_widget (mainwin, TRUE, mainwin_shaded_close, 264, 3);
-    button_on_release (mainwin_shaded_close, (ButtonCB) aud_drct_quit);
+    button_on_release (mainwin_shaded_close, (ButtonCB) handle_window_close);
 
     mainwin_srew = button_new_small (8, 7);
     window_put_widget (mainwin, TRUE, mainwin_srew, 169, 4);
@@ -1479,12 +1475,6 @@ static gboolean state_cb (GtkWidget * widget, GdkEventWindowState * event,
     return TRUE;
 }
 
-static gboolean delete_cb (GtkWidget * widget, GdkEvent * event, void * unused)
-{
-    aud_drct_quit ();
-    return TRUE;
-}
-
 static void mainwin_draw (GtkWidget * window, cairo_t * cr)
 {
     gint width = config.player_shaded ? MAINWIN_SHADED_WIDTH : active_skin->properties.mainwin_width;
@@ -1519,10 +1509,8 @@ mainwin_create_window(void)
 
     ui_main_evlistener_init();
 
-    g_signal_connect ((GObject *) mainwin, "window-state-event", (GCallback)
-     state_cb, NULL);
-    g_signal_connect ((GObject *) mainwin, "delete-event", (GCallback)
-     delete_cb, NULL);
+    g_signal_connect ((GObject *) mainwin, "window-state-event", (GCallback) state_cb, NULL);
+    g_signal_connect ((GObject *) mainwin, "delete-event", (GCallback) handle_window_close, NULL);
 }
 
 void mainwin_unhook (void)
